| digestdm | R Documentation |
This dataset contains example data to calculate the apparent digestibility of two diets that differ in their dry matter mass fraction and in the mass fraction of digestibility markers in the feces.
A tibble with two rows and four columns:
character; feed identifier.
numeric; mass fraction of dry matter in the feed. Data reported as value between 0 and 1, corresponding to g/g.
numeric; mass fraction of digestibility marker in feed. Data reported as value between 0 and 1, corresponding to g/g.
numeric; mass fraction of digestibility marker in feces. Data reported as value between 0 and 1, corresponding to g/g.
digestdm
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.