| digestnut | R Documentation |
This dataset contains example data for the calculation of apparent digestibility coefficients for the digestibility of nitrogen in the dry matter fraction of an aquaculture feed.
A tibble with two rows and six columns:
character; feed identifier.
numeric; mass fraction of dry matter in the feed. Data reported as value between 0 and 1, corresponding to g/g.
numeric; mass fraction of nitrogen in feed. Data reported as value between 0 and 1, corresponding to g/g.
numeric; mass fraction of digestibility marker in feed. Data reported as value between 0 and 1, corresponding to g/g.
numeric; mass fraction of nitrogen in feces in g/kg.
numeric; mass fraction of digestibility marker in feces. Data reported as value between 0 and 1, corresponding to g/g.
digestnut
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.