| gbw | R Documentation |
A function that calculates the geometric mean of the initial and final bodyweight.
gbw(ibw, fbw)
ibw |
numeric; initial bodyweight weight in grams. |
fbw |
numeric; final bodyweight in grams. |
While the arithmetic mean assumes a linear relationship between the averaged numbers, the geometric mean accounts for the non-linear and potentially variable nature of animal growth.
numeric value that is the geometric mean bodyweight.
Anıl Axel Tellbüscher
data(weight2)
dplyr::mutate(weight2, GMBW = gbw(ibw_g, fbw_g))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.