mbw: Metabolic bodyweight (MBW)

View source: R/growth.R

mbwR Documentation

Metabolic bodyweight (MBW)

Description

The metabolic bodyweight is the rate of energy expenditure in dependence of the bodyweight of an organism. The metabolism of larger animals is generally slower per Kg when comparing with smaller animals. An exponent between 0-1 takes that relationship into account in a fairly simple equation.

Usage

mbw(ibw, fbw, mb_exp = 0.8)

Arguments

ibw

a numeric value that is providing the initial weight in grams.

fbw

a numeric value that is providing the final weight in grams.

mb_exp

a numeric value between 0-1 providing the exponent. Default is 0.8 adapted to most fish species.

Details

The default exponent is suited to fish only. It was set to 0.8 based on Lupatsch et al. (2003) and should be adjusted to other scenarios.

Value

returns a numeric value that is the metabolic bodyweight.

Author(s)

Anıl Axel Tellbüscher

Davide A. Machado e Silva

Madhav Karthikeyan

References

Lupatsch, I. et al. (2003): Comparison of energy and protein efficiency among three fish species gilthead sea bream (Sparus aurata), European sea bass (Dicentrarchus labrax) and white grouper (Epinephelus aeneus): energy expenditure for protein and lipid deposition. Aquaculture 225, p.175-189.

Examples

data(weight2)
dplyr::mutate(weight2, MBW = mbw(ibw_g, fbw_g))


aquacultuR documentation built on Jan. 26, 2026, 5:07 p.m.