rearing: Rearing data from the first polyculture experiment

rearingR Documentation

Rearing data from the first polyculture experiment

Description

A dataset containing feed quantities fed per tank and the average water temperature over all tanks stocked with pikeperch oder sturgeon. The variables are as follows:

Format

A data frame containing 24 rows and four columns:

tank

character; unique identifier for each fish tank.

feed_g

numeric; total feed input in gram over the duration of the experiment.

temp_C

numeric; average water temperature in degrees Celsius.

duration

numeric; total duration of the experiment in days.

Examples

rearing


aquacultuR documentation built on Jan. 26, 2026, 5:07 p.m.