| agr | R Documentation |
A function that calculates the Absolute Growth Rate (AGR), also denoted as Weight Gain (WG) when applied to weight data.
agr(ibw, fbw, duration)
ibw |
numeric; value that is providing the initial body weight in grams. |
fbw |
numeric; value that is providing the final body weight in grams. |
duration |
numeric value that is providing the duration of the experiment in days. |
returns a numeric value which is the total body weight change over the specified period of time.
Anıl Axel Tellbüscher
Madhav Karthikeyan
Davide A. Machado e Silva
Lugert, V., Thaller, G., Tetens, J., Schulz, C., & Krieter, J. (2016): A review on fish growth calculation: multiple functions in fish production and their specific application. Reviews in Aquaculture, 8, p.30–42.
Hopkins K.D. (1992) Reporting fish growth, a review of the basics. Journal of World Aquaculture Society, 23, p.173-179
data(weight2)
dplyr::mutate(weight2, AGR = agr(ibw_g, fbw_g, duration = 84))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.