View source: R/feed_conversion.R
| fcr | R Documentation |
A function that calculates the Feed Conversion Ratio (FCR) based on the Initial Body weight (IBW; ibw) in gram (g), the Final Body Weight (FBW; fbw) in gram (g), the Feed fed (Ff; ff) in gram and the dry matter (DM; dm) content of the feed in percent.
fcr(ibw, fbw, feed, dm = 1)
ibw |
numeric; value that is providing the initial weight in grams. |
fbw |
numeric; value that is providing the final weight in grams. |
feed |
numeric; value providing the feed fed in grams during the experiment. |
dm |
numeric; value within the interval of ]0:1], indicating the relative dry matter content of the feed. |
The Feed Conversion Ratio (FCR) describes the amount of feed on dry matter (DM) basis that is required to gain 1 kg of body weight on wet weight basis. Depending on whether the Feed fed refers to the total amount of feed administered or the total amount corrected for non-eaten feed, the result resembles the economic FCR (eFCR) or the biological FCR (bFCR), respectively (Glencross et al., 2024).
returns a numeric value that is the FCR.
Anıl Axel Tellbüscher
Lugert, V., Thaller, G., Tetens, J., Schulz, C., & Krieter, J. (2016): A review on fish growth calculation: multiple functions in fish production and their specific application. Reviews in Aquaculture, 8, p.30–42.
Glencross, B., Bachis, E., Robb, D., & Newton, R. (2024): The evolution of sustainability metrics for the marine ingredient sector: Moving towards holistic assessments of aquaculture feed. Reviews in Fisheries Science & Aquaculture, 32(4), p.545-561.
# Feed intake = 1500 g
# Feed dry matter = 0.96 g/g (= 96%)
# Initial bodyweight = 100 g
# Final bodyweight = 1000 g
fcr(100, 1000, 1500, 0.96)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.