| mbw | R Documentation |
The metabolic bodyweight is the rate of energy expenditure in dependence of the bodyweight of an organism. The metabolism of larger animals is generally slower per Kg when comparing with smaller animals. An exponent between 0-1 takes that relationship into account in a fairly simple equation.
mbw(ibw, fbw, mb_exp = 0.8)
ibw |
a numeric value that is providing the initial weight in grams. |
fbw |
a numeric value that is providing the final weight in grams. |
mb_exp |
a numeric value between 0-1 providing the exponent. Default is 0.8 adapted to most fish species. |
The default exponent is suited to fish only. It was set to 0.8 based on Lupatsch et al. (2003) and should be adjusted to other scenarios.
returns a numeric value that is the metabolic bodyweight.
Anıl Axel Tellbüscher
Davide A. Machado e Silva
Madhav Karthikeyan
Lupatsch, I. et al. (2003): Comparison of energy and protein efficiency among three fish species gilthead sea bream (Sparus aurata), European sea bass (Dicentrarchus labrax) and white grouper (Epinephelus aeneus): energy expenditure for protein and lipid deposition. Aquaculture 225, p.175-189.
data(weight2)
dplyr::mutate(weight2, MBW = mbw(ibw_g, fbw_g))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.