| rgr | R Documentation |
A function that calculates the Relative Growth Rate (RGR), which is the relative weight increase per time unit.
rgr(ibw, fbw, duration, mean_fun = "init")
ibw |
numeric; provides the initial weight in gram. |
fbw |
numeric; provides the final weight in gram. |
duration |
numeric; duration of the growth experiment. |
mean_fun |
character; specifies how ("init", "geometric" or "arithmetic") to calculate the denominator. Default: "init". |
either a single numeric value or vector holding the calculated RGR values. Multiply by 100 for conversion into percentage.
Anıl Axel Tellbüscher
Lugert, V., Thaller, G., Tetens, J., Schulz, C., & Krieter, J. (2016): A review on fish growth calculation: multiple functions in fish production and their specific application. Reviews in Aquaculture, 8, p.30–42.
data(weight2)
dplyr::mutate(weight2, RGR = rgr(ibw_g, fbw_g, duration = 84))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.